@@ -14,6 +14,9 @@ class AbstractSession(abc.ABC):
     def start_job(self, script):
         return self._transport.start_job(script)
 
+    def stop_job(self, job_identifier):
+        return self._transport.stop_job(job_identifier)
+
     def get_jobs(self):
         return self._transport.get_jobs()
 
